from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = [line.strip() for line in f]

with open('README.md') as f:
    long_description = f.read()

with open('VERSION') as f:
    version = f.read()

setup(name='pypear',
      version=version,
      author='Brian McConnel',
      author_email='brianmcconnel@gmail.com',
      url='https://github.com/brianmcconnel/pypear',
      description='Adequate terminal based python development.',
      license='MIT',
      packages=find_packages(),
      package_data={"pypear": ["vim/plugins.zip"]},
      long_description=long_description,
      long_description_content_type='text/markdown',
      entry_points={'console_scripts': ['pypear = pypear.install:install']},
      classifiers=("Programming Language :: Python :: 3",
                   "License :: OSI Approved :: MIT License",
                   "Operating System :: OS Independent",),
      keywords='python tmux vim pypear',
      requires=requirements,
      zip_safe=False)



from zipfile import ZipFile
import os
import pathlib
import shutil

current_path = str(pathlib.Path(__file__).parent.absolute())
install_dir = str(pathlib.Path.home()) + '/.pypear'
vim_template = str(pathlib.Path.home()) + '/.pypear/plugins/vimrc'


def install():
    with ZipFile(current_path + '/vim/plugins.zip') as zip:
        if os.path.exists(install_dir):
            shutil.rmtree(install_dir)
        os.mkdir(install_dir)
        zip.extractall(path=install_dir)


def vimrc_prepend(file_name):
    with open(file_name, 'r') as f:
        content = f.read()
    with open(file_name, 'w') as f:
        f.write('pypear\n')
        f.write(content)


def gen_vimrc():
    with open(vim_template) as f:
        result = f.read()
    return result
